@@ -118,8 +118,8 @@ struct _PangoAttribute
  *
  * Type of a function filtering a list of attributes.
  *
- * Return value: %TRUE if the attribute should be kept, %FALSE if it should be
- * filtered out.
+ * Return value: %TRUE if the attribute should be selected for
+ * filtering, %FALSE otherwise.
  **/
 typedef gboolean (*PangoAttrFilterFunc) (PangoAttribute *attribute,
 					 gpointer        user_data);
@@ -293,6 +293,13 @@ gboolean pango_parse_markup (const char                 *markup_text,
 			     gunichar                   *accel_char,
 			     GError                    **error);
 
+GMarkupParseContext * pango_markup_parser_new (gunichar               accel_marker);
+gboolean              pango_markup_parser_finish (GMarkupParseContext   *context,
+                                                  PangoAttrList        **attr_list,
+                                                  char                 **text,
+                                                  gunichar              *accel_char,
+                                                  GError               **error);
+
 G_END_DECLS
 
 #endif /* __PANGO_ATTRIBUTES_H__ */
